/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "talk.h"
#define SCALE 16

void pokerTalkInit(poker_t *poker) {
  poker->talkText = NULL;
  poker->talkTextInfo = NULL;
  poker->lastWidth = 0, poker->lastHeight = 0;
}

void pokerTalkDispose(poker_t *poker) {
  if(poker->talkTextInfo == NULL) return;
  fontTextInfoDispose(poker->talkTextInfo);
  primitiveDispose(&poker->talkPrimitive);
}

void pokerTalkTextRebuffer(poker_t *poker, render_t *render) {
  // Check if we need to force a redraw or not.
  if(poker->talkText == NULL || poker->lastWidth != render->width) {
    if(poker->talkTextInfo != NULL) {
      fontTextInfoDispose(poker->talkTextInfo);
      primitiveDispose(&poker->talkPrimitive);
    }
  }
  if(poker->talkText == NULL) return;

  // Rebuffer
  poker->talkTextInfo = fontTextClamp(&poker->font, poker->talkText, SCALE,
    render->width
  );
  fontTextInit(&poker->font, &poker->talkPrimitive, poker->talkTextInfo);
}

void pokerTalkRender(poker_t *poker, render_t *render) {
  pokerTalkTextRebuffer(poker, render);

  if(poker->talkTextInfo == NULL) return;
  shaderUsePosition(&poker->shader, 0,0,0, 0,0,0);
  shaderUseTexture(&poker->shader, &poker->font.texture);
  primitiveDraw(&poker->talkPrimitive, 0, -1);
}

void pokerTalk(poker_t *poker, char *text) {
  poker->talkText = text;
}